"""
PyAsterisk.py $Id: $

Wrapper classes for the Asterisk Embedded Python implementation.

This software is distributed under the terms of the GNU GPL, version 2.0 or
later, a copy of which you should have recieved in the source distribution 
with this file or which is also available at http://www.fsf.org/licences/gpl.html,
with one additional clause:

Permission is granted to link this program at runtime with the chan_g729a.so
library distributed by Digium Inc. in ftp://ftp.digium.com/pub/asterisk/g729
or any other implementation of the proprietary and patent-encumbered pseudo
standard known as G.729, G.729A or G.729B.

        Copyleft (.) 2004 Consultants Ars Informatica S.A.R.F.
"""

def verbose(s):
    """
    For some unknown reason, the ast_verbose function
    does not append a carriage return.
    """
    from asterisk import ast_verbose
    return ast_verbose(s + '\n')

class Channel:
    """
    @class Channel

    This is a wrapper class to represent an Asterisk
    channel. Channel variables are in particular supported
    via dictionary-like syntax. This is so you don't have
    to use the lower level get/set routines.
    """
    def __init__(self, chan):
        from asterisk import ast_channel_getname
        self.__channel__ = chan
        self.name = ast_channel_getname(chan)
        
    def __getitem__(self, item):
        from asterisk import pbx_builtin_getvar_helper
        return pbx_builtin_getvar_helper(self.__channel__, str(item))

    def __setitem__(self, item, value):
        from asterisk import pbx_builtin_setvar_helper
        pbx_builtin_setvar_helper(self.__channel__, str(item), str(value))

    def hangup(self):
        from asterisk import ast_softhangup
        return ast_softhangup(self.__channel__, 0)

class CallDetailRecord:
    """
    class CallDetailRecord

    This is a wrapper class to represent a Call Detail Record
    so it can be easily accessed without resorting to the lower
    level api defined in the PyAsterisk C module.
    """
    def __init__(self, cdr):
        import asterisk

        for field in ["accountcode", "src", "dst", "dcontext", "clid",
                      "dstchannel", "lastapp", "lastdata", "disposition",
                      "start", "answer", "end", "duration", "billsec", 
                      "amaflags", "uniqueid", "userfield"]:
            func = getattr(asterisk, "ast_cdr_get_" + field)
            setattr(self, field, func(cdr))

        self.channel = Channel(asterisk.ast_cdr_get_channelp(cdr))
