"""
PyAsteriskConfig.py $Id: $

Definitions of three functions, cdr, start, and stop that are called by
res_python.c and cdr_python.c. This one of two main points of entry into
the interpreted Python code, the other being via the dialplan with 
app_python.c.

This software is distributed under the terms of the GNU GPL, version 2.0 or
later, a copy of which you should have recieved in the source distribution 
with this file or which is also available at http://www.fsf.org/licences/gpl.html,
with one additional clause:

Permission is granted to link this program at runtime with the chan_g729a.so
library distributed by Digium Inc. in ftp://ftp.digium.com/pub/asterisk/g729
or any other implementation of the proprietary and patent-encumbered pseudo
standard known as G.729, G.729A or G.729B.

        Copyleft (.) 2004 Consultants Ars Informatica S.A.R.F.
"""

listen_addr = ("0.0.0.0", 8192)
certdir = "/etc/asterisk/certs"

global xmlrpc_server
xmlrpc_server = None

from asterisk import *
from PyAsterisk import *

def cdr(c):
    """
    Call Detail Record handler. This is called with an opaque CDR object.
    """

    ## instantiate a CallDetailRecord wrapper class
    calldetail = CallDetailRecord(c)

def start():
    """
    This is the main thread of res_python. It is not suppposed to return.
    It is the place to run persistent servers, such as the example XMLRPC
    server that exposes methods of the AsteriskXMLRPC module.
    """
    from SecureXMLRPCServer import SecureXMLRPCServer
    from AsteriskXMLRPC import AsteriskXMLRPC
    
    ast_verbose("Starting PyAsteriskXMLRPC Service on %s\n" % (listen_addr,))

    global xmlrpc_server
    xmlrpc_server = SecureXMLRPCServer(listen_addr, certdir)
    method_provider = AsteriskXMLRPC(xmlrpc_server)

    xmlrpc_server.register_instance(method_provider)
    xmlrpc_server.register_introspection_functions()
    xmlrpc_server.register_multicall_functions()

    xmlrpc_server.set_server_title("PyAsterisk")
    xmlrpc_server.set_server_name("server.example.com")
    xmlrpc_server.set_server_documentation(method_provider.__doc__)

    ## By default xmlrpc server only accepts RPC2 requests
    ## from localhost. Add hosts to the ACL lists to allow 
    ## for remote control.
    # xmlrpc_server.acl.append("192.168.0.1")
    # xmlrpc_server.acl.append("128.100.100.1")

    xmlrpc_server.serve_forever() # until the socket gets closed
    xmlrpc_server = None

def stop():
    """
    This function is called when the res_python is unloaded and it
    should stop any servers or background processes that are running,
    and do any necessary cleanup.
    """
    ## Shut down the XMLRPC listening thread...
    global xmlrpc_server
    if xmlrpc_server:
        xmlrpc_server.server_close()
    
