
%{
/*
 * CVS $Id: asterisk.i,v 1.1 2004/11/03 00:52:30 ww Exp $
 *
 * helpers.i -- SWIG Interface definition for 
 *              Embedded Python Interpreter for Asterisk
 *
 * This software is distributed under the terms of the GNU GPL, version 2.0 or
 * later, a copy of which you should have recieved in the source distribution 
 * with this file or which is also available at http://www.fsf.org/licences/gpl.html
 *
 * In addition to the terms set out by the GNU GPL, an additional permission is
 * required due to the unfortunate circumstance that our international telcommunications
 * regulatory body, the ITU has given a patent-encumbered encoding/decoding 
 * algorithm the status of a standard. Worse, this standard has become the only
 * choice for many operations in telecommunications due to interconnection requirements
 * between autonomous networks despite the availability of good alternatives. The
 * use of this codec, G.729, and its variants, is discouraged.
 *
 * In the interests of minimizing technical barriers to communication, please
 * encourage your suppliers and customers to support free alternatives like
 * GSM or Speex.
 *
 * If you *absolutely must* use G.729:
 * 
 * Permission is granted to link this program at runtime with the chan_g729a.so
 * library distributed by Digium Inc. in ftp://ftp.digium.com/pub/asterisk/g729
 * or any other implementation of the proprietary and patent-encumbered pseudo
 * standard known as G.729, G.729A or G.729B.
 *
 */

  /*
   * Helper function to convert an ast_channel pointer to a python
   * object, mostly for use in app_python.c
   */
  PyObject *PyAsterisk_BuildChannelObj(struct ast_channel *c) {
    PyObject *resultobj;
    resultobj = SWIG_NewPointerObj((void *)c, SWIGTYPE_p_ast_channel, 0);
    return resultobj;
  }
%}

%inline %{

void ast_lock_channel(struct ast_channel *c) {
  if(!c) return;
  ast_mutex_lock(&c->lock);
}

void ast_unlock_channel(struct ast_channel *c) {
  if(!c) return;
  ast_mutex_unlock(&c->lock);
}

char *ast_channel_getname(struct ast_channel *c) {
  if(!c) return;
  return c->name;
}

int ast_originate(char *src,
		  char *outctx, char *outext, int outprio,
		  char *cid, char *account, char *vars, int timeout)
{
  int reason = 0, ret;

  if(!src || !outctx || !outext)
    return -1;
  if(!timeout) timeout = 30000;
  if(!vars) vars = "";

  ast_verbose("Calling %s/%s from %s as %s for %s\n", outctx, outext, src, cid, account);

  Py_BEGIN_ALLOW_THREADS
  ret = ast_pbx_outgoing_exten("Local", AST_FORMAT_SLINEAR, src, timeout,
			     outctx, outext, outprio,
			     &reason, 1, cid, vars, account); 
  Py_END_ALLOW_THREADS
  return ret;
}

%}
